Documentation
¶
Overview ¶
Package cmd is used for Cobra and Viper integration.
0.3.12 Created by senzing-factory/github-action-make-go-github-file.yaml on Sun Oct 26 21:27:00 UTC 2025
Index ¶
Constants ¶
const ( Short string = "Check the environment in which senzing-tool runs" Use string = "check-self" Long string = ` check-self long description. ` )
Variables ¶
var CompletionCmd = &cobra.Command{ Use: "completion", Short: "Generate bash completion for the command", Long: `To load completions, run: source < (check-self completion) To load completions automatically on login, add this line to your .bashrc file: source < (check-self completion) `, RunE: func(cmd *cobra.Command, args []string) error { _ = cmd _ = args return completionAction(os.Stdout) }, }
CompletionCmd represents the completion command.
var ContextVariables = append(ContextVariablesForMultiPlatform, ContextVariablesForOsArch...)
var ContextVariablesForMultiPlatform = []option.ContextVariable{ option.ConfigPath, option.Configuration, option.CoreLogLevel, option.CoreSettings, option.DatabaseURL, option.GrpcURL, option.InputURL, option.LicenseDaysLeft, option.LicenseRecordsPercent, option.LicenseStringBase64, option.LogLevel, option.ObserverURL, option.ResourcePath, option.SenzingDirectory, option.SupportPath, }
var ContextVariablesForOsArch = []option.ContextVariable{}
var DocsCmd = &cobra.Command{ Use: "docs", Short: "Generate documentation for the command", RunE: func(cmd *cobra.Command, args []string) error { _ = args dir, err := cmd.Flags().GetString("dir") if err != nil { return wraperror.Errorf(err, "getting 'dir' value") } if dir == "" { if dir, err = os.MkdirTemp("", "check-self"); err != nil { return wraperror.Errorf(err, "constructing cobra.Command") } } return DocsAction(os.Stdout, dir) }, }
DocsCmd represents the docs command.
var RootCmd = &cobra.Command{ Use: Use, Short: Short, Long: Long, PreRun: PreRun, RunE: RunE, Version: Version(), }
RootCmd represents the command.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the RootCmd.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.